<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fn="http://www.w3.org/2005/xpath-functions" xmlns:hl7="urn:hl7-org:v3" xmlns:hl7fi="urn:hl7finland" xmlns:java="http://xml.apache.org/xslt/java" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:kela="urn:kela">
	<xsl:output version="1.0" method="xml" encoding="UTF-8" indent="no"/>
	<!-- Locations of image files -->
	<!-- Path, must end with \ (windows) or / (unix) -->
	<xsl:variable name="imagesPath" select="''"/>
	<xsl:variable name="kantaLogoFI" select="concat($imagesPath,'KanTa_FI_RGB_POS.png')"/>
	<xsl:variable name="kantaLogoSE" select="concat($imagesPath,'KanTa_SV_RGB_POS.png')"/>
	<xsl:variable name="kelaLogoFI" select="concat($imagesPath,'Kela.png')"/>
	<xsl:variable name="kelaLogoSE" select="concat($imagesPath,'Fpa.png')"/>
	<!-- ################# -->
	<xsl:variable name="XML" select="/"/>
	<xsl:variable name="cancellation">
		<xsl:choose>
			<xsl:when test="$XML//hl7:section[(hl7:code/@code='21' or hl7:code/@code='1.2.246.537.6.12.2002.330.21') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']">
				<xsl:value-of select="true()"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="false()"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="representativeInvolved">
		<xsl:choose>
			<xsl:when test="$XML//hl7:section[(hl7:code/@code='9' or hl7:code/@code='1.2.246.537.6.12.2002.330.9') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:text">
				<xsl:value-of select="true()"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="false()"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<!-- på svenska? -->
	<xsl:variable name="sv">
		<xsl:choose>
			<xsl:when test="string($XML/hl7:ClinicalDocument/hl7:languageCode/@code)='sv'">
				<xsl:value-of select="true()"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="false()"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:decimal-format name="format1" grouping-separator=" " decimal-separator=","/>
	<xsl:variable name="fo:layout-master-set">
		<fo:layout-master-set>
			<fo:simple-page-master master-name="page-master-149464384" margin-left="0.60in" margin-right="0.8in" page-height="11.69in" page-width="8.27in" margin-top="0.10in" margin-bottom="0.3in">
				<fo:region-body margin-top="1.75in" margin-bottom="0.6in" column-count="1" column-gap="0.50in"/>
				<fo:region-before region-name="page-header" extent="1.75in"/>
				<fo:region-after region-name="page-footer" extent="0.49in"/>
			</fo:simple-page-master>
		</fo:layout-master-set>
	</xsl:variable>
	<xsl:template match="/">
		<fo:root font-size="12pt">
			<xsl:copy-of select="$fo:layout-master-set"/>
			<fo:page-sequence master-reference="page-master-149464384" initial-page-number="auto" format="1" force-page-count="no-force">
				<fo:static-content flow-name="page-header">
					<fo:block margin="0pt">
						<fo:table table-layout="fixed" width="100%">
							<fo:table-column column-width="proportional-column-width(1)"/>
							<fo:table-column column-width="proportional-column-width(1)"/>
							<fo:table-body start-indent="0pt">
								<fo:table-row>
									<fo:table-cell display-align="center">
										<fo:block text-align="left">
											<xsl:choose>
												<xsl:when test="$sv='true'">
													<fo:external-graphic content-height="0.55in" scaling="uniform" src="{$kelaLogoSE}"/>
												</xsl:when>
												<xsl:otherwise>
													<fo:external-graphic content-height="0.55in" scaling="uniform" src="{$kelaLogoFI}"/>
												</xsl:otherwise>
											</xsl:choose>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell padding="2pt" display-align="center">
										<fo:block text-align="right">
											<xsl:choose>
												<xsl:when test="$sv='true'">
													<fo:external-graphic content-height="0.55in" scaling="uniform" src="{$kantaLogoSE}"/>
												</xsl:when>
												<xsl:otherwise>
													<fo:external-graphic content-height="0.55in" scaling="uniform" src="{$kantaLogoFI}"/>
												</xsl:otherwise>
											</xsl:choose>
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
					</fo:block>
					<fo:block text-align="left" margin-left="2in">
						<fo:inline font-weight="bold">
							<xsl:choose>
								<xsl:when test="$cancellation='true'">
									<xsl:choose>
										<xsl:when test="$sv='true'">
											<xsl:text>ÅTERKALLELSE AV SAMTYCKE</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text>SUOSTUMUKSEN PERUUTUS</xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
										<xsl:when test="$sv='true'">
											<xsl:text>SAMTYCKE</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text>SUOSTUMUS</xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
						</fo:inline>
						<fo:block/>
						<xsl:choose>
							<xsl:when test="$sv='true'">
								<fo:inline font-style="italic">
									<xsl:text>Utlämnade av uppgifter som lagrats</xsl:text>
								</fo:inline>
								<fo:block/>
								<xsl:choose>
									<xsl:when test="$representativeInvolved='true'">
										<fo:inline font-style="italic">
											<xsl:text>i patientdataarkivet till en annan laglig företrädare</xsl:text>
										</fo:inline>
									</xsl:when>
									<xsl:otherwise>
										<fo:inline font-style="italic">
											<xsl:text>i patientdataarkivet</xsl:text>
										</fo:inline>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<fo:inline font-style="italic">
									<xsl:text>Potilastiedon arkistoon </xsl:text>
								</fo:inline>
								<fo:block/>
								<fo:inline font-style="italic">
									<xsl:text>tallennettujen tietojen luovuttaminen</xsl:text>
								</fo:inline>
							</xsl:otherwise>
						</xsl:choose>
						<fo:block/>
					</fo:block>
				</fo:static-content>
				<fo:static-content flow-name="page-footer">
					<fo:block-container height="0.49in" overflow="hidden" display-align="after">
						<fo:block>
							<fo:table width="100%" table-layout="fixed" border-spacing="2pt">
								<fo:table-column column-width="proportional-column-width(1)"/>
								<fo:table-column column-width="5.070in"/>
								<fo:table-column column-width="0.580in"/>
								<fo:table-body start-indent="0pt">
									<fo:table-row>
										<fo:table-cell font-size="10pt" padding="2pt" display-align="center">
											<fo:block text-align="right">
												<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='27' or hl7:code/@code='1.2.246.537.6.12.2002.330.27') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:text"/>
											</fo:block>
										</fo:table-cell>
										<fo:table-cell font-size="10pt" padding="0" display-align="center">
											<fo:block text-align="center">
												<fo:inline>
													<xsl:choose>
														<xsl:when test="$sv='true'">
															<xsl:text>Utskriftsdatum: </xsl:text>
														</xsl:when>
														<xsl:otherwise>
															<xsl:text>Tulostuspäivämäärä: </xsl:text>
														</xsl:otherwise>
													</xsl:choose>
												</fo:inline>
												<fo:inline>
													<xsl:choose>
														<xsl:when test="system-property('xsl:vendor-url')='http://www.microsoft.com' or system-property('xsl:vendor-url')='http://www.altova.com'">
															<xsl:value-of select="kela:currentDate()"/>
														</xsl:when>
														<xsl:otherwise>
															<xsl:value-of select="java:format(java:java.text.SimpleDateFormat.new('dd.MM.yyyy'), java:java.util.Date.new())"/>
														</xsl:otherwise>
													</xsl:choose>
												</fo:inline>
											</fo:block>
											<fo:block text-align="center">
												<fo:inline>
													<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='28' or hl7:code/@code='1.2.246.537.6.12.2002.330.28') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:text"/>
												</fo:inline>
											</fo:block>
										</fo:table-cell>
										<fo:table-cell font-size="10pt" padding="0" display-align="center">
											<fo:block text-align="right">
												<xsl:call-template name="pages"/>
											</fo:block>
										</fo:table-cell>
									</fo:table-row>
								</fo:table-body>
							</fo:table>
						</fo:block>
					</fo:block-container>
				</fo:static-content>
				<fo:flow flow-name="xsl-region-body">
					<xsl:choose>
						<xsl:when test="$sv='true'">
							<fo:block text-align="justify" margin="0pt" space-before="1.12em" space-after="1.12em">
								<fo:inline>
									<xsl:text>Jag har fått del av de uppgifter som finns som bilaga till detta samtycke och som gäller Kanta-tjänsterna och det elektroniska arkivet samt fått information om hur de samtycken och förbud som jag ger påverkar behandlingen av mina patientuppgifter.</xsl:text>
								</fo:inline>
							</fo:block>
							<fo:block text-align="justify" margin="0pt" space-before="1.12em" space-after="1.12em">
								<fo:inline>
									<xsl:text>Jag ger mitt samtycke till att de uppgifter om mig som finns lagrade i Patientdataarkivet får lämnas ut via de riksomfattande informationssystemtjänsterna till tillhandahållare av hälso- och sjukvårdstjänster för ordnande och tillhandahållande av min personliga hälso- och sjukvård.</xsl:text>
								</fo:inline>
							</fo:block>
							<fo:block text-align="justify" margin="0pt" space-before="1.12em" space-after="1.12em">
								<fo:inline>
									<xsl:text>Mitt samtycke omfattar alla de uppgifter om mig som finns lagrade i Patientdataarkivet, och även de uppgifter som kommer att lagras där efter att jag gett mitt samtycke. Samtycket gäller tills vidare.</xsl:text>
								</fo:inline>
							</fo:block>
							<fo:block text-align="justify" margin="0pt" space-before="1.12em" space-after="1.12em">
								<fo:inline>
									<xsl:text>Om jag så önskar kan jag hos en tillhandahållare av hälso- och sjukvårdstjänster eller via e-tjänsten Mina Kanta-sidor återkalla det samtycke som jag har gett.</xsl:text>
								</fo:inline>
							</fo:block>
							<fo:block text-align="justify" margin="0pt" space-before="1.12em" space-after="1.12em">
								<fo:inline>
									<xsl:text>Om jag så önskar kan jag hos en tillhandahållare av hälso- och sjukvårdstjänster eller via e-tjänsten Mina Kanta-sidor förbjuda utlämnande av sådana uppgifter som jag särskilt specificerar. De förbud som jag eventuellt har anmält till sjukvårdsdistriktets gemensamma patientregister gäller på samma sätt som tidigare.</xsl:text>
								</fo:inline>
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block text-align="justify" margin="0pt" space-before="1.12em" space-after="1.12em">
								<fo:inline>
									<xsl:text>Olen saanut ne tiedot, jotka koskevat Kanta-palveluja, Potilastiedon arkistoa sekä antamieni suostumusten ja kieltojen vaikutuksia potilastietojeni käsittelyyn. Saamani tiedot ovat tämän suostumuksen liitteenä.</xsl:text>
								</fo:inline>
							</fo:block>
							<fo:block text-align="justify" margin="0pt" space-before="1.12em" space-after="1.12em">
								<fo:inline>
									<xsl:text>Annan suostumukseni siihen, että Potilastiedon arkistoon minusta tallennettuja tietoja saa luovuttaa valtakunnallisten tietojärjestelmäpalvelujen kautta terveydenhuollon palvelujen antajille henkilökohtaisen terveyden- ja sairaanhoitoni järjestämiseksi ja toteuttamiseksi.</xsl:text>
								</fo:inline>
							</fo:block>
							<fo:block text-align="justify" margin="0pt" space-before="1.12em" space-after="1.12em">
								<fo:inline>
									<xsl:text>Suostumus kattaa kaikki minusta Potilastiedon arkistoon tallennetut ja myös suostumuksen antamisen jälkeen tallennettavat tiedot. Suostumus on voimassa toistaiseksi.</xsl:text>
								</fo:inline>
							</fo:block>
							<fo:block text-align="justify" margin="0pt" space-before="1.12em" space-after="1.12em">
								<fo:inline>
									<xsl:text>Voin halutessani peruuttaa antamani suostumuksen joko terveydenhuollon palvelujen antajan luona tai Omakanta-palvelussa.</xsl:text>
								</fo:inline>
							</fo:block>
							<fo:block text-align="justify" margin="0pt" space-before="1.12em" space-after="1.12em">
								<fo:inline>
									<xsl:text>Voin halutessani kieltää erikseen määrittelemieni tietojen luovuttamisen joko terveydenhuollon palvelujen antajan luona tai Omakanta-palvelussa. Mahdolliset sairaanhoitopiirin yhteiseen potilastietorekisteriin tekemäni kiellot ovat voimassa kuten aiemmin.</xsl:text>
								</fo:inline>
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
					<fo:block/>
					<fo:block margin="0pt" space-before="0.12em" space-after="1.12em">
						<fo:inline font-weight="bold" keep-with-next.within-page="always">
							<xsl:choose>
								<xsl:when test="$sv='true'">
									<xsl:text>Patientens personuppgifter</xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Potilaan henkilötiedot</xsl:text>
								</xsl:otherwise>
							</xsl:choose>
						</fo:inline>
					</fo:block>
					<fo:table table-layout="fixed" width="100%" border-spacing="2pt">
						<fo:table-column column-width="proportional-column-width(1)"/>
						<fo:table-column column-width="proportional-column-width(1)"/>
						<fo:table-body start-indent="0pt">
							<fo:table-row keep-with-next="always">
								<fo:table-cell padding="2pt" display-align="center">
									<fo:block text-align="left">
										<fo:inline>
											<xsl:choose>
												<xsl:when test="$sv='true'">
													<xsl:text>Efternamn och alla förnamn</xsl:text>
												</xsl:when>
												<xsl:otherwise>
													<xsl:text>Sukunimi, etunimet</xsl:text>
												</xsl:otherwise>
											</xsl:choose>
										</fo:inline>
									</fo:block>
								</fo:table-cell>
								<fo:table-cell padding="2pt" display-align="center">
									<fo:block text-align="left">
										<fo:inline>
											<xsl:choose>
												<xsl:when test="$sv='true'">
													<xsl:text>Personbeteckning</xsl:text>
												</xsl:when>
												<xsl:otherwise>
													<xsl:text>Henkilötunnus</xsl:text>
												</xsl:otherwise>
											</xsl:choose>
										</fo:inline>
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
							<fo:table-row>
								<fo:table-cell padding="2pt" display-align="center">
									<fo:block text-align="left">
										<fo:inline>
											<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='5' or hl7:code/@code='1.2.246.537.6.12.2002.330.5') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:text"/>
										</fo:inline>
									</fo:block>
								</fo:table-cell>
								<fo:table-cell padding="2pt" display-align="center">
									<fo:block text-align="left">
										<fo:inline>
											<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='6' or hl7:code/@code='1.2.246.537.6.12.2002.330.6') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:text"/>
										</fo:inline>
									</fo:block>
								</fo:table-cell>
							</fo:table-row>
						</fo:table-body>
					</fo:table>
					<fo:block/>
					<xsl:if test="$representativeInvolved='true'">
						<fo:block margin="0pt" space-before="1.12em" space-after="1.12em" keep-with-next.within-page="always">
							<fo:inline font-weight="bold">
								<xsl:choose>
									<xsl:when test="$cancellation='false'">
										<xsl:choose>
											<xsl:when test="$sv='true'">
												<xsl:text>Patientens lagliga företrädares personuppgifter (om det är han eller hon som meddelar samtycket)</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>Potilaan laillisen edustajan henkilötiedot, jos hän toimii suostumuksen antajana</xsl:text>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:when>
									<xsl:otherwise>
										<xsl:choose>
											<xsl:when test="$sv='true'">
												<xsl:text>Patientens lagliga företrädares personuppgifter. Samtycket har getts av den lagliga företrädaren.</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>Potilaan laillisen edustajan henkilötiedot. Laillinen edustaja on toiminut suostumuksen antajana.</xsl:text>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:otherwise>
								</xsl:choose>
							</fo:inline>
						</fo:block>
						<fo:block margin="0pt" space-before="1.12em" space-after="1.12em" keep-with-next.within-page="always">
							<fo:inline>
								<xsl:choose>
									<xsl:when test="$sv='true'">
										<xsl:text>En laglig företrädare kan till exempel vara ett minderårigt barns vårdnadshavare eller en intressebevakare som utsetts att sköta ärenden som gäller patientens hälsa.</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:text>Laillinen edustaja voi olla esimerkiksi alaikäisen lapsen huoltaja tai edunvalvoja, jonka tehtäväksi on määrätty potilaan terveyttä koskevien asioiden hoitaminen.</xsl:text>
									</xsl:otherwise>
								</xsl:choose>
							</fo:inline>
						</fo:block>
						<fo:block/>
						<fo:table table-layout="fixed" width="100%" border-spacing="2pt">
							<fo:table-column column-width="proportional-column-width(1)"/>
							<fo:table-column column-width="proportional-column-width(1)"/>
							<fo:table-body start-indent="0pt">
								<fo:table-row keep-with-next="always">
									<fo:table-cell padding="2pt" display-align="center">
										<fo:block text-align="left">
											<fo:inline>
												<xsl:choose>
													<xsl:when test="$sv='true'">
														<xsl:text>Efternamn och alla förnamn</xsl:text>
													</xsl:when>
													<xsl:otherwise>
														<xsl:text>Sukunimi, etunimet</xsl:text>
													</xsl:otherwise>
												</xsl:choose>
											</fo:inline>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell padding="2pt" display-align="center">
										<fo:block text-align="left">
											<fo:inline>
												<xsl:choose>
													<xsl:when test="$sv='true'">
														<xsl:text>Personbeteckning</xsl:text>
													</xsl:when>
													<xsl:otherwise>
														<xsl:text>Henkilötunnus</xsl:text>
													</xsl:otherwise>
												</xsl:choose>
											</fo:inline>
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
								<fo:table-row>
									<fo:table-cell padding="2pt" display-align="center">
										<fo:block text-align="left">
											<fo:inline>
												<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='9' or hl7:code/@code='1.2.246.537.6.12.2002.330.9') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:text"/>
											</fo:inline>
										</fo:block>
									</fo:table-cell>
									<fo:table-cell padding="2pt" display-align="center">
										<fo:block text-align="left">
											<fo:inline>
												<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='10' or hl7:code/@code='1.2.246.537.6.12.2002.330.10') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:text"/>
											</fo:inline>
										</fo:block>
									</fo:table-cell>
								</fo:table-row>
							</fo:table-body>
						</fo:table>
						<fo:block/>
					</xsl:if>
					<fo:block margin="0pt" space-before="1.12em" space-after="1.12em" keep-with-next.within-page="always">
						<fo:inline font-weight="bold">
							<xsl:choose>
								<xsl:when test="$cancellation='true'">
									<xsl:choose>
										<xsl:when test="$sv='true'">
											<xsl:text>Gällande samtycke</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text>Voimassaoleva suostumus</xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
										<xsl:when test="$sv='true'">
											<xsl:text>Underskrift av den som ger samtycket</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text>Suostumuksen antajan allekirjoitus</xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
						</fo:inline>
					</fo:block>
					<xsl:variable name="cannotSignOptIn" select="$XML//hl7:section[(hl7:code/@code='11' or hl7:code/@code='1.2.246.537.6.12.2002.330.11') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:entry/hl7:observation/hl7:value/@value"/>
					<xsl:if test="string($cannotSignOptIn)='true'">
						<fo:block margin="0pt" space-before="1.12em" space-after="1.12em" keep-with-next.within-page="always">
							<fo:inline>
								<xsl:choose>
									<xsl:when test="$sv='true'">
										<xsl:text>Patienten är till exempel på grund av underårig, sjukdom eller skada oförmögen att underteckna handlingen. Motivering:&#160;</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:text>Potilas ei ole alaikäisyyden, sairauden tai vamman takia kykenevä allekirjoittamaan Kanta-arkiston suostumusta Peruste:&#160;</xsl:text>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='12' or hl7:code/@code='1.2.246.537.6.12.2002.330.12') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:text"/>
							</fo:inline>
						</fo:block>
						<fo:block margin="0pt" space-before="1.12em" space-after="1.12em" keep-with-next.within-page="always">
							<fo:inline font-weight="bold">
								<xsl:choose>
									<xsl:when test="$sv='true'">
										<xsl:text>För patientens räkning</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:text>Potilaan puolesta</xsl:text>
									</xsl:otherwise>
								</xsl:choose>
							</fo:inline>
						</fo:block>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="$cancellation='true'">
							<fo:block margin="0pt" space-after="1.12em">
								<fo:inline>
									<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='14' or hl7:code/@code='1.2.246.537.6.12.2002.330.14') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:text"/>
									<xsl:text>&#160;&#160;&#160;</xsl:text>
								</fo:inline>
								<fo:inline>
									<xsl:for-each select="$XML//hl7:section[(hl7:code/@code='15' or hl7:code/@code='1.2.246.537.6.12.2002.330.15') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:entry/hl7:observation/hl7:value">
										<xsl:call-template name="formatdatetime">
											<xsl:with-param name="datetime" select="@value"/>
											<xsl:with-param name="skipsec" select="true"/>
										</xsl:call-template>
									</xsl:for-each>
								</fo:inline>
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block margin="0pt" space-before="1.5em" keep-with-next.within-page="always">
								<fo:inline>
									<xsl:text>____________________________________&#160;&#160;&#160;</xsl:text>
								</fo:inline>
								<fo:inline>
									<xsl:for-each select="$XML//hl7:section[(hl7:code/@code='15' or hl7:code/@code='1.2.246.537.6.12.2002.330.15') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:entry/hl7:observation/hl7:value">
										<xsl:call-template name="formatdatetime">
											<xsl:with-param name="datetime" select="@value"/>
											<xsl:with-param name="skipsec" select="true"/>
										</xsl:call-template>
									</xsl:for-each>
								</fo:inline>
							</fo:block>
							<fo:block margin="0pt" space-after="1.12em">
								<fo:inline>
									<xsl:choose>
										<xsl:when test="$XML//hl7:section[(hl7:code/@code='14' or hl7:code/@code='1.2.246.537.6.12.2002.330.14') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']//hl7:given[@qualifier='CL']">
											<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='14' or hl7:code/@code='1.2.246.537.6.12.2002.330.14') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']//hl7:given[@qualifier='CL']"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='14' or hl7:code/@code='1.2.246.537.6.12.2002.330.14') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']//hl7:given[1]"/>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:text>&#160;</xsl:text>
									<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='14' or hl7:code/@code='1.2.246.537.6.12.2002.330.14') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']//hl7:family"/>
								</fo:inline>
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
					<fo:block/>
					<xsl:if test="$cancellation='true'">
						<fo:block margin="0pt" space-before="1.12em" space-after="1.12em">
							<fo:inline font-weight="bold">
								<xsl:choose>
									<xsl:when test="$sv='true'">
										<xsl:text>Återkallelse av samtycke</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:text>Suostumuksen peruuttaminen</xsl:text>
									</xsl:otherwise>
								</xsl:choose>
							</fo:inline>
						</fo:block>
						<fo:block margin="0pt" space-before="1.12em" space-after="1.12em">
							<fo:inline>
								<xsl:choose>
									<xsl:when test="$sv='true'">
										<xsl:text>Jag återkallar det samtycke som jag har gett ovan, enligt vilket de uppgifter om mig som har lagrats i Patientdataarkivet har fått lämnas ut för ordnande och tillhandahållande av min personliga hälso- och sjukvård. </xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:text>Peruutan edellä olevan suostumuksen, jonka perusteella Potilastiedon arkistoon tallennettuja tietojani on saanut luovuttaa henkilökohtaisen terveyden- ja sairaanhoitoni järjestämiseksi ja toteuttamiseksi. </xsl:text>
									</xsl:otherwise>
								</xsl:choose>
							</fo:inline>
						</fo:block>
						<xsl:variable name="cannotSignOptInCancellation" select="$XML//hl7:section[(hl7:code/@code='18' or hl7:code/@code='1.2.246.537.6.12.2002.330.18') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']//hl7:entry/hl7:observation/hl7:value/@value"/>
						<xsl:choose>
							<xsl:when test="string($cannotSignOptInCancellation)='true'">
								<fo:block margin="0pt" space-before="1.12em" space-after="1.12em" keep-with-next.within-page="always">
									<fo:inline>
										<xsl:choose>
											<xsl:when test="$sv='true'">
												<xsl:text>Patienten är till exempel på grund av sjukdom eller skada oförmögen att underteckna återkallelsen av sitt samtycke. Motivering:&#160;</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>Potilas ei ole esimerkiksi sairauden tai vamman takia kykenevä allekirjoittamaan suostumuksen peruutusta. Peruste:&#160;</xsl:text>
											</xsl:otherwise>
										</xsl:choose>
										<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='19' or hl7:code/@code='1.2.246.537.6.12.2002.330.19') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:text"/>
									</fo:inline>
								</fo:block>
								<fo:block margin="0pt" space-before="1.12em" space-after="1.12em" keep-with-next.within-page="always">
									<fo:inline font-weight="bold">
										<xsl:choose>
											<xsl:when test="$sv='true'">
												<xsl:text>För patientens räkning</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>Potilaan puolesta</xsl:text>
											</xsl:otherwise>
										</xsl:choose>
									</fo:inline>
								</fo:block>
							</xsl:when>
							<xsl:otherwise>
								<fo:block margin="0pt" space-before="1.12em" space-after="1.12em" keep-with-next.within-page="always">
									<fo:inline font-weight="bold">
										<xsl:choose>
											<xsl:when test="$sv='true'">
												<xsl:text>Patientens underskrift</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>Potilaan allekirjoitus</xsl:text>
											</xsl:otherwise>
										</xsl:choose>
									</fo:inline>
								</fo:block>
							</xsl:otherwise>
						</xsl:choose>
						<fo:block margin="0pt" space-before="3.5em" keep-with-next.within-page="always">
							<fo:inline>
								<xsl:text>____________________________________&#160;&#160;&#160;</xsl:text>
							</fo:inline>
							<fo:inline>
								<xsl:for-each select="$XML//hl7:section[(hl7:code/@code='22' or hl7:code/@code='1.2.246.537.6.12.2002.330.22') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:entry/hl7:observation/hl7:value">
									<xsl:call-template name="formatdatetime">
										<xsl:with-param name="datetime" select="@value"/>
										<xsl:with-param name="skipsec" select="true"/>
									</xsl:call-template>
								</xsl:for-each>
							</fo:inline>
						</fo:block>
						<fo:block margin="0pt" space-after="1.12em">
							<fo:inline>
								<xsl:choose>
									<xsl:when test="$XML//hl7:section[(hl7:code/@code='21' or hl7:code/@code='1.2.246.537.6.12.2002.330.21') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']//hl7:given[@qualifier='CL']">
										<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='21' or hl7:code/@code='1.2.246.537.6.12.2002.330.21') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']//hl7:given[@qualifier='CL']"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='21' or hl7:code/@code='1.2.246.537.6.12.2002.330.21') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']//hl7:given[1]"/>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:text>&#160;</xsl:text>
								<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='21' or hl7:code/@code='1.2.246.537.6.12.2002.330.21') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']//hl7:family"/>
							</fo:inline>
						</fo:block>
						<fo:block/>
					</xsl:if>
					<fo:block margin="0pt" space-before="1.12em" space-after="1.12em">
						<fo:inline font-weight="bold">
							<xsl:choose>
								<xsl:when test="$sv='true'">
									<xsl:text>Handlingen lagrades av</xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>Asiakirjan tallentaja</xsl:text>
								</xsl:otherwise>
							</xsl:choose>
						</fo:inline>
					</fo:block>
					<fo:block margin="0pt" space-before="1.12em" space-after="1.12em">
						<fo:inline>
							<xsl:value-of select="$XML//hl7:section[(hl7:code/@code='24' or hl7:code/@code='1.2.246.537.6.12.2002.330.24') and hl7:code/@codeSystem='1.2.246.537.6.12.2002.330']/hl7:text"/>
						</fo:inline>
						<fo:inline id="SV_RefID_PageTotal"/>
					</fo:block>
				</fo:flow>
			</fo:page-sequence>
		</fo:root>
	</xsl:template>
	<xsl:template name="formatdatetime">
		<xsl:param name="datetime"/>
		<xsl:param name="skiptime"/>
		<!-- skips time if value is not empty -->
		<xsl:param name="skipsec"/>
		<!-- skips seconds if value is not empty -->
		<!-- pp-->
		<xsl:if test='substring ($datetime, 7, 2)!=""'>
			<xsl:choose>
				<xsl:when test="substring($datetime,7,1)!='0'">
					<xsl:value-of select="substring ($datetime,7, 2)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="substring ($datetime,8, 1)"/>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:text>.</xsl:text>
		</xsl:if>
		<!-- kk-->
		<xsl:if test='substring ($datetime, 5, 2)!=""'>
			<xsl:choose>
				<xsl:when test="substring($datetime,5,1)!='0'">
					<xsl:value-of select="substring ($datetime,5, 2)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="substring ($datetime,6, 1)"/>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:text>.</xsl:text>
		</xsl:if>
		<!-- vvvv-->
		<xsl:value-of select="substring ($datetime, 1, 4)"/>
		<xsl:if test="$skiptime=''">
			<xsl:if test='substring ($datetime, 9, 2)!=""'>
				<xsl:text>&#160;</xsl:text>
				<!-- hh-->
				<xsl:choose>
					<xsl:when test="substring($datetime,9,1)!='0'">
						<xsl:value-of select="substring ($datetime,9, 2)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="substring ($datetime,10, 1)"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<!-- mm -->
			<xsl:if test='substring ($datetime, 11, 2)!=""'>
				<xsl:text>.</xsl:text>
				<xsl:value-of select="substring ($datetime,11, 2)"/>
			</xsl:if>
			<!-- ss -->
			<xsl:if test='substring ($datetime, 13, 2)!="" and $skipsec=""'>
				<xsl:text>.</xsl:text>
				<xsl:value-of select="substring ($datetime,13, 2)"/>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<xsl:template name="pages">
		<fo:block>
			<fo:page-number/> (<fo:page-number-citation ref-id="SV_RefID_PageTotal"/>)</fo:block>
	</xsl:template>
	<msxml:script xmlns:msxml="urn:schemas-microsoft-com:xslt" language="JavaScript" implements-prefix="kela">
		function currentDate(){
			var date = new Date();
			return date.getDate() + '.' + [date.getMonth() + 1] + "." + date.getYear();
		};
	</msxml:script>
</xsl:stylesheet>
